/* *******************************************************************
   Board Settings for
   RGBW LED WIFI Controller H801
   Controller:   ESP8266
   Setting:      Generic 8266   
                 1MB: (FS256KB: OTA ~274KB)  
   Description:  https://werner.rothschopf.net/microcontroller/202106_esp8266_h801_dimmer_pwm_en.htm
 
   Amazon:       https://amzn.to/3Br4BS5
   Aliexpress:   https://s.click.aliexpress.com/e/_AB5FtK

  ********************************************************************/
 
#pragma once
#if USE_BOARD == 79                    // ESP8266 H801 Dimmer Wifi board
#define TXT_BOARDNAME "H801 Dimmer Wifi" // the name of the board

HardwareSerial &Terminal = Serial1;    // if you need debug messages, you have to send them to Serial1(!) on the H801 PWM Board

//declare the pins                     // on the H801 dimmer:
const byte pwmRedPin = 15;             // GPIO15 red
const byte pwmGreenPin = 13;           // GPIO13 green
const byte pwmBluePin = 12;            // GPIO12 blue
const byte pwmW1Pin = 14;              // GPIO14 white warm
const byte pwmW2Pin = 4;               // GPIO04 white cold
const byte ledGreenPin = 1;            // GPIO01/D10 the green SMD LED on the PCB (left top corner)
const byte ledRedPin = 5;              // GPIO05/D1 the red SMD LED on the PCB (left bottom corner)
const byte flashPin = 0;               // GPIO00/D3 flash Jumper
// RX Serial =  3                      // as header available - can be used for sketch upload
// TX Serial1 =  2                     // as header available - but Serial1 (!)

// assign pins to the struct arrays:
// The H801 board has only the flashPin exposed for the program jumper
Pin inputPin[] {
  // the pin    a name for the website
  {flashPin,    "Jumper"},
};

// there are two LEDs on the PCB which can be used to indicate states of your program
OutputPin outputPin[] {
  // the pin     a name        LOW active (or high active)
  {ledRedPin,   "board red",   LOW},
  {ledGreenPin, "board green", LOW}
};

// the H801 offers 5 PWM outputs connected to MOSFETS
PWMPin pwmPin[] {
  // the pin     a name          a PWM value
  {pwmRedPin,   "red",           0},
  {pwmGreenPin, "green",         0},
  {pwmBluePin,  "blue",          0},
  {pwmW1Pin,    "warm white",    0},
  {pwmW2Pin,    "cold white",    0}
};

// this board has no shift registers
#define NO_SHIFTPIN

const uint8_t wifiActivityPin = ledRedPin;  // this board has an internal red LED on the PCB - set to 255 if activity LED is not needed
#endif
